@@ -25,6 +25,11 @@ from plotly.subplots import make_subplots
 # Clears display if you need to manual loop
 from IPython.display import clear_output
 
+# For accessing supporting docs within supporting folder
+import pkg_resources
+
+
+
 
 
 ###################################################
@@ -862,7 +867,10 @@ def NSSP_Element_Grabber(data,Timed = True, Priority_only=False, outfile='None')
     
     
     # Read in reader file as pandas dataframe
-    reader = pd.read_excel('../data/processed/NSSP_Element_Reader.xlsx')
+
+    DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
+    FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/NSSP_Element_Reader.xlsx')
+    reader = pd.read_excel(FILE)
     
     # Create empty dataframe with rows we want interpreted from reader file
     df = pd.DataFrame(columns=reader['Processed Column'])
@@ -971,7 +979,11 @@ def priority_cols(df, priority='both', extras=None, drop_cols=None):
     ------------
     -import pandas as pd
     '''
-    reader = pd.read_excel('NSSP_Element_Reader.xlsx') 
+
+
+    this_dir, this_filename = os.path.split(__file__)
+    DATA_PATH = os.path.join(this_dir, "supporting", "NSSP_Element_Reader.xlsx")
+    reader = pd.read_excel(DATA_PATH)
    
     # There is a chance that the user removed priority columns from the input dataframe for their own reasons.
     #     Therefore we only want to look at cases where the input dataframe columns match the reader processed column.
@@ -1047,7 +1059,10 @@ def validity_check(df, Timed=True):
     
     
     # Read in the validity key
-    key = pd.read_excel('NSSP_Validity_Reader.xlsx')
+
+    DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
+    FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/NSSP_Validity_Reader.xlsx')
+    key = pd.read_excel(FILE)
 
     # There is a chance that the user had decided to get rid of columns we typically check for validity.
     #      Therefore we need to only loop through 'key' rows that match our input dataframe's columns.
@@ -1161,7 +1176,9 @@ def Visualize_Facility_DQ(df, fac_name, hide_yticks = False, Timed = True):
     hosp_visits = df[df.FACILITY_NAME==fac_name]
 
     # Read in our validity key
-    key = pd.read_excel('NSSP_Validity_Reader.xlsx')
+    DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
+    FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/NSSP_Validity_Reader.xlsx')
+    key = pd.read_excel(FILE)
 
     # There is a chance that the user had decided to get rid of columns we typically check for validity.
     #      Therefore we need to only loop through 'key' rows that match our input dataframe's columns.
@@ -1444,7 +1461,10 @@ def issues_in_messages(df, Timed=True, combine_issues_on_message = False, split_
     ########################################################################################################
 
     # Load our key and set its index
-    key = pd.read_excel('Message_Corrector_Key.xlsx')
+    DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
+    FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/Message_Corrector_Key.xlsx')
+    key = pd.read_excel(FILE)
+
     key = key.set_index('Element')
 
     # Initialize df_out
@@ -1760,14 +1780,23 @@ def validity_and_completeness_report(df,description='long',visit_count=False,out
     #####################################################################################################################
 
     if description == 'long':
-        key = pd.read_excel('Message_Corrector_Key.xlsx')
+
+        DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
+        FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/Message_Corrector_Key.xlsx')
+        key = pd.read_excel(FILE)
+
+
         key = key.set_index('Element')
         for i in np.arange(0,len(empty)):
             el = empty.loc[i,'Element']
             empty.loc[i,'Description'] = key.loc[el,'Description']
 
     elif description == 'short':
-        key = pd.read_excel('NSSP_Element_Reader.xlsx')
+
+        DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
+        FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/NSSP_Element_Reader.xlsx')
+        key = pd.read_excel(FILE)
+
         key = key.set_index('Processed Column')
         for i in np.arange(0,len(empty)):
             el = empty.loc[i,'Element']
